# python-ldap2jira

Set of utilities for finding jira accounts with LDAP check and optional file map.

[![Test](https://github.com/RedHat-Eng-PGM/python-ldap2jira/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/RedHat-Eng-PGM/python-ldap2jira/actions/workflows/test.yml)
[![Coverage](https://codecov.io/gh/RedHat-Eng-PGM/python-ldap2jira/branch/master/graph/badge.svg?token=WCXC71LMUA)](https://codecov.io/gh/RedHat-Eng-PGM/python-ldap2jira)
[![Pypi Upload](https://github.com/RedHat-Eng-PGM/python-ldap2jira/actions/workflows/pypi-upload.yml/badge.svg)](https://github.com/RedHat-Eng-PGM/python-ldap2jira/actions/workflows/pypi-upload.yml)
[![Pypi Version](https://img.shields.io/pypi/v/ldap2jira.svg)](https://pypi.org/project/ldap2jira/)


https://pypi.org/project/ldap2jira/
